==> open-xchange-guard_1.0.0.orig.tar.bz2: open-xchange-guard-1.0.0/com.openexchange.guard/src/com/openexchange/guard/server/OxCookie.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.server;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;



/**
 * Handles getting OX Authorization Cookie, parsing, and returning info
 * 
 * @author greg
 */
public class OxCookie {

	private static Logger logger = LoggerFactory.getLogger(OxCookie.class);
	
    String JSESSIONID = "";

    String oxSecret = "";

    String oxSecretValue = "";
    
    String oxPublicSessionName = "";

    String oxPublicSession = "";

    String oxSession = "";

    String oxSessionValue = "";

    String OxReaderID = "";
    
    String language = "en_US";

    Boolean cookieAuth = false;

    OxCookie(javax.servlet.http.Cookie[] cookies) {
        try {
            if (cookies == null)
                return;
            if (cookies.length > 0) {// Make sure the cookies are present
                for (int i = 0; i < cookies.length; i++) {
                    String name = cookies[i].getName();
                    if (name.startsWith("JSESSIONID"))
                        JSESSIONID = checkCR(cookies[i].getValue());
                    if (name.startsWith("open-xchange-secret")) {
                        oxSecret = name;
                        oxSecretValue = checkCR(cookies[i].getValue());
                        cookieAuth = true; // Set as authorized if we have the secret data
                    }
                    if (name.startsWith("language")) {
                    	language = checkCR(cookies[i].getValue());
                    }
                    if (name.startsWith("open-xchange-session")) {
                        oxSession = name;
                        oxSessionValue = checkCR(cookies[i].getValue());
                        cookieAuth = true; // Set as authorized if we have the secret data
                    }
                    if (name.startsWith("open-xchange-public-session"))
                    	oxPublicSessionName = name;
                        oxPublicSession = checkCR(cookies[i].getValue());
                    if (name.startsWith("OxReaderID"))
                        OxReaderID = checkCR(cookies[i].getValue());
                }
            }
        } catch (Exception ex) {
            logger.error("Error handling cookie", ex);
        }
    }

    public String getJSESSIONID() {
        return (JSESSIONID);
    }

    public Boolean isAuth() {
        return (cookieAuth);

    }

    public String getOXPublicSession() {
        return (oxPublicSession);
    }

    public String getOXSecret() {
        return (oxSecret);
    }

    public String getOXSecretValue() {
        return (oxSecretValue);
    }

    public String getCookieHeader() {
        String value = "language=" + language + "; JSESSIONID=" + JSESSIONID + "; " + (oxSession.equals("") ? "" : ( oxSession + "=" + oxSessionValue + "; ")) + oxSecret + "=" + oxSecretValue + "; " + oxPublicSessionName+ "=" + oxPublicSession + ";";
        return (value);

    }
    
    private String checkCR (String data) {
    	return (data.replace("\r", "").replace("\n", ""));
    }
}

==> open-xchange-guard_1.2.0.orig.tar.bz2: open-xchange-guard-1.2.0/com.openexchange.guard/src/com/openexchange/guard/server/OxCookie.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.server;

import java.util.ArrayList;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;



/**
 * Handles getting OX Authorization Cookie, parsing, and returning info
 * 
 * @author greg
 */
final class cookie {
	public String name;
	public String value;
}

public class OxCookie {

	private static Logger logger = LoggerFactory.getLogger(OxCookie.class);
	
    public String JSESSIONID = "";
    
    ArrayList <cookie> secretcookie = new ArrayList <cookie> ();
    
    ArrayList <cookie> publicsession = new ArrayList <cookie> ();
    
    ArrayList <cookie> session = new ArrayList <cookie> ();

    public String OxReaderID = "";
    
    String language = "en_US";

    Boolean cookieAuth = false;

    OxCookie(javax.servlet.http.Cookie[] cookies) {
        try {
            if (cookies == null)
                return;
            if (cookies.length > 0) {// Make sure the cookies are present
                for (int i = 0; i < cookies.length; i++) {
                    String name = cookies[i].getName();
                    if (name.startsWith("JSESSIONID"))
                        JSESSIONID = checkCR(cookies[i].getValue());
                    if (name.startsWith("open-xchange-secret")) {
                    	cookie ck = new cookie();
                    	ck.name = name;
                    	ck.value = checkCR(cookies[i].getValue());
                    	secretcookie.add(ck);
                        cookieAuth = true; // Set as authorized if we have the secret data
                    }
                    if (name.startsWith("language")) {
                    	language = checkCR(cookies[i].getValue());
                    }
                    if (name.startsWith("open-xchange-session")) {
                    	cookie ck = new cookie();
                    	ck.name = name;
                    	ck.value = checkCR(cookies[i].getValue());
                    	session.add(ck);
                        cookieAuth = true; // Set as authorized if we have the secret data
                    }
                    if (name.startsWith("open-xchange-public-session")) {
                    	cookie ck = new cookie();
                    	ck.name = name;
                    	ck.value = checkCR(cookies[i].getValue());
                    	publicsession.add(ck);
                    }
                    if (name.startsWith("OxReaderID"))
                        OxReaderID = checkCR(cookies[i].getValue());
                }
            }
        } catch (Exception ex) {
            logger.error("Error handling cookie", ex);
        }
    }

    public String getJSESSIONID() {
        return (JSESSIONID);
    }

    public Boolean isAuth() {
        return (cookieAuth);

    }


    public String getCookieHeader() {
    	StringBuilder sb = new StringBuilder();
    	sb.append("language=" + language + "; JSESSIONID=" + JSESSIONID + "; ");
        for (int i = 0; i < session.size(); i++) {
        	sb.append(session.get(i).name + "=" + session.get(i).value + "; ");
        }
        for (int j = 0; j < secretcookie.size(); j++) {
        	sb.append(secretcookie.get(j).name + "=" + secretcookie.get(j).value + "; ");
        }
        for (int k = 0; k < publicsession.size(); k++) {
        	sb.append(publicsession.get(k).name + "=" + publicsession.get(k).value + "; ");
        }
        return (sb.toString());

    }
    
    private String checkCR (String data) {
    	return (data.replace("\r", "").replace("\n", ""));
    }
}
